==> haskell-natural-transformation-0.4.1-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-natural-transformation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 natural-transformation
version:              0.4.1
visibility:           public
id:                   natural-transformation-0.4.1-4HUJmEEqhKy62HoDzeydgv
key:                  natural-transformation-0.4.1-4HUJmEEqhKy62HoDzeydgv
license:              BSD-3-Clause
copyright:            Copyright (c) 2015-2016 The University of Kansas
maintainer:           Andy Gill <andygill@ku.edu>
author:               Andy Gill
stability:            Provisional
homepage:             https://github.com/ku-fpg/natural-transformation
synopsis:             A natural transformation package.
description:
    A natural transformation transforms a container @f a@ into another
    container @g a@. Natural transformations act as functor morphisms
    in category theory.

    The naming of '\''~>'\'', '\'':~>'\'' and '\''$$'\'' were taken,
    with permission, from Edward Kmett'\''s @indexed@ package.

category:             Control
abi:                  54037d21dc00b4c020235574cbd447df
exposed:              True
exposed-modules:      Control.Natural Control.Natural.RULES Control.Object
import-dirs:          /usr/lib/ghc-9.4.8/site-local/natural-transformation-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/natural-transformation-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/natural-transformation-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-natural-transformation
hs-libraries:         HSnatural-transformation-0.4.1-4HUJmEEqhKy62HoDzeydgv
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-natural-transformation/html/natural-transformation.haddock

haddock-html:         /usr/share/doc/haskell-natural-transformation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-natural-transformation-0.4.1-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-natural-transformation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 natural-transformation
version:              0.4.1
visibility:           public
id:                   natural-transformation-0.4.1-3HtOGeuvPldKqi1F0qfsHY
key:                  natural-transformation-0.4.1-3HtOGeuvPldKqi1F0qfsHY
license:              BSD-3-Clause
copyright:            Copyright (c) 2015-2016 The University of Kansas
maintainer:           Andy Gill <andygill@ku.edu>
author:               Andy Gill
stability:            Provisional
homepage:             https://github.com/ku-fpg/natural-transformation
synopsis:             A natural transformation package.
description:
    A natural transformation transforms a container @f a@ into another
    container @g a@. Natural transformations act as functor morphisms
    in category theory.

    The naming of '\''~>'\'', '\'':~>'\'' and '\''$$'\'' were taken,
    with permission, from Edward Kmett'\''s @indexed@ package.

category:             Control
abi:                  81f515d8c9855880e51550d12083d514
exposed:              True
exposed-modules:      Control.Natural Control.Natural.RULES Control.Object
import-dirs:          /usr/lib/ghc-9.4.8/site-local/natural-transformation-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/natural-transformation-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/natural-transformation-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-natural-transformation
hs-libraries:         HSnatural-transformation-0.4.1-3HtOGeuvPldKqi1F0qfsHY
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-natural-transformation/html/natural-transformation.haddock

haddock-html:         /usr/share/doc/haskell-natural-transformation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
